# BracketFormatter

This is a simple Python log formatter to output streaming log entries (e.g. going to STDOUT) with a custom formatting - such that they have the appearance of:

![screenshot.png](screenshot.png)

It was mostly written for my own use - but if it's useful to anyone else, then please feel free to use it.
